@@ -32,6 +32,7 @@
 #endif
 
 /* XXX monsters.c data and funcs */
+extern void update_mon(int mon);
 extern void mon_acts(int mon);
 extern void death_drop(int mon);
 extern void print_mon_name(int mon, int article);
@@ -42,6 +43,7 @@ extern int ood(int power, int ratio);
 extern int get_random_pmon(void);
 extern void damage_mon(int mon, int amount, int by_you);
 extern int mon_can_pass(int mon, int y, int x);
+extern int mon_visible(int mon);
 extern void move_mon(int mon, int y, int x);
 extern int teleport_mon(int mon);	/* Randomly relocate monster. */
 extern int teleport_mon_to_you(int mon);	/* Relocate monster to your vicinity. */
